#include <vector>
#include <detector/filtering-grid-detector.h>
#include "point_set/mutable-point-set-list.h"
#include "detector/harris-detector.h"
#include "extractor/sift-extractor.h"
#include "extractor/location-extractor.h"

using namespace std;
using namespace libpmk;
using namespace libpmk_features;

int main(int argc, char** argv) {
  MutablePointSetList features;
  MutablePointSetList locations;
  
  HarrisDetector detector;
  detector.SetBinaryPath("~/bin/h_affine.ln");

  SIFTExtractor sift_extractor;
  sift_extractor.SetBinaryPath("~/bin/compute_descriptors.ln");

  LocationExtractor loc_extractor;
  

  vector<InterestPoint> interest_points;
  detector.DetectInterestPoints("example.jpg", &interest_points);
  
  PointSet ps = sift_extractor.ExtractFeatures("example.jpg", &interest_points);
  features.add_point_set(ps);

  PointSet loc = loc_extractor.ExtractFeatures("example.jpg", &interest_points);
  locations.add_point_set(loc);

  features.WriteToFile("output.psl");
  locations.WriteToFile("locs.psl");

  return 0;
}
